@@ -1,4 +1,4 @@
-#include <clap/clap.h>
+#include <clap/all.h>
 
 // The purpose of this file is to check that all headers compile
 
