@@ -1,7 +1,7 @@
 // qtractorAudioClip.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -175,6 +175,9 @@ qtractorAudioClip::qtractorAudioClip ( const qtractorAudioClip& clip )
 	setClipGain(clip.clipGain());
 	setClipPanning(clip.clipPanning());
 
+	setFadeInType(clip.fadeInType());
+	setFadeOutType(clip.fadeOutType());
+
 	// Clone the audio peak, if any...
 	if (clip.m_pPeak)
 		m_pPeak = new qtractorAudioPeak(*clip.m_pPeak);
@@ -256,7 +259,7 @@ bool qtractorAudioClip::openAudioFile ( const QString& sFilename, int iMode )
 	setDirty(false);
 
 	// Register file path...
-	pSession->files()->addClipItem(qtractorFileList::Audio, this, bWrite);
+	pSession->files()->addClipItemEx(qtractorFileList::Audio, this, bWrite);
 
 	// New key-data sequence...
 	if (!bWrite) {
@@ -367,10 +370,6 @@ void qtractorAudioClip::closeAudioFile (void)
 		#endif
 		}
 		m_pData = nullptr;
-		// Unregister file path...
-		qtractorSession *pSession = qtractorSession::getInstance();
-		if (pSession)
-			pSession->files()->removeClipItem(qtractorFileList::Audio, this);
 	}
 
 	if (m_pKey) {
