@@ -1,7 +1,7 @@
 // qtractorClipCommand.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2023, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -78,8 +78,6 @@ public:
 	void wsolaClip(qtractorClip *pClip,
 		bool bWsolaTimeStretch, bool bWsolaQuickSeek);
 
-	void reopenClip(qtractorClip *pClip, bool bClose = false);
-
 	// Special clip record methods.
 	bool addClipRecord(qtractorTrack *pTrack, unsigned long iFrameTime);
 	bool addClipRecordTake(qtractorTrack *pTrack, qtractorClip *pClip,
@@ -102,6 +100,9 @@ public:
 
 protected:
 
+	// When clips need to reopem.
+	void reopenClip(qtractorClip *pClip, bool bClose = false);
+
 	// Common executive method.
 	virtual bool execute(bool bRedo);
 
@@ -239,6 +240,92 @@ private:
 };
 
 
+//----------------------------------------------------------------------
+// class qtractorClipContextCommand - declaration. (virtual class)
+//
+
+class qtractorClipContextCommand : public qtractorCommand
+{
+public:
+
+	// Constructor.
+	qtractorClipContextCommand(const QString& sName);
+	// Destructor.
+	virtual ~qtractorClipContextCommand();
+
+	// Composite command methods.
+	void addMidiClipContext(qtractorMidiClip *pMidiClip);
+
+	// Composite predicate.
+	bool isEmpty() const;
+
+	// Virtual command methods.
+	bool redo();
+	bool undo();
+
+protected:
+
+	// Main executive method.
+	bool execute(bool bRedo);
+
+	// Virtual executive method.
+	struct MidiClipCtx {
+		QString filename;
+		unsigned long offset;
+		unsigned long length;
+	};
+
+	virtual bool executeMidiClipContext(
+		qtractorMidiClip *pMidiClip, const MidiClipCtx& mctx, bool bRedo) = 0;
+
+private:
+
+	int m_iRedoCount;
+
+	typedef QHash<qtractorMidiClip *, MidiClipCtx> MidiClipCtxs;
+
+	MidiClipCtxs m_midiClipCtxs;
+};
+
+
+//----------------------------------------------------------------------
+// class qtractorClipSaveFileCommand - declaration.
+//
+
+class qtractorClipSaveFileCommand : public qtractorClipContextCommand
+{
+public:
+
+	// Constructor.
+	qtractorClipSaveFileCommand();
+
+protected:
+
+	// Context (visitor) executive method.
+	bool executeMidiClipContext(
+		qtractorMidiClip *pMidiClip, const MidiClipCtx& mctx, bool bRedo);
+};
+
+
+//----------------------------------------------------------------------
+// class qtractorClipUnlinkCommand - declaration.
+//
+
+class qtractorClipUnlinkCommand : public qtractorClipContextCommand
+{
+public:
+
+	// Constructor.
+	qtractorClipUnlinkCommand();
+
+protected:
+
+	// Context (visitor) executive method.
+	bool executeMidiClipContext(
+		qtractorMidiClip *pMidiClip, const MidiClipCtx& mctx, bool bRedo);
+};
+
+
 //----------------------------------------------------------------------
 // class qtractorClipToolCommand - declaration.
 //
@@ -270,9 +357,6 @@ public:
 
 protected:
 
-	// Filename and length swap transaction...
-	void swapMidiClipCtx( qtractorMidiClip *pMidiClip);
-
 	// Execute tempo-map/time-sig commands.
 	void executeTimeScaleNodeCommands(bool bRedo);
 
@@ -287,17 +371,7 @@ private:
 	// When tempo-map node commands.
 	QList<qtractorTimeScaleNodeCommand *> m_timeScaleNodeCommands;
 
-	struct MidiClipCtxState {
-		QString filename;
-		unsigned long length;
-	};
-
-	struct MidiClipCtx {
-		MidiClipCtxState pre;
-		MidiClipCtxState post;
-	};
-
-	QHash<qtractorMidiClip *, MidiClipCtx> m_midiClipCtxs;
+	qtractorClipSaveFileCommand *m_pClipSaveFileCommand;
 };
 
 
