@@ -1,7 +1,7 @@
 // qtractorMidiClip.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2023, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -26,8 +26,6 @@
 #include "qtractorMidiCursor.h"
 #include "qtractorMidiFile.h"
 
-#include "qtractorTimeScale.h"
-
 #include <QPoint>
 #include <QSize>
 
@@ -136,7 +134,7 @@ public:
 	QString toolTip() const;
 
 	// Auto-save to (possible) new file revision.
-	bool saveCopyFile(bool bUpdate);
+	bool saveCopyFile(const QString& sFilename, bool bUpdate);
 
 	// MIDI clip export method.
 	typedef void (*ClipExport)(qtractorMidiSequence *, void *);
@@ -162,8 +160,7 @@ public:
 
 		// Constructor.
 		Data(unsigned short iFormat)
-			: m_iFormat(iFormat), m_pSeq(new qtractorMidiSequence(
-				QString(), 0, qtractorTimeScale::TICKS_PER_BEAT_HRQ)) {}
+			: m_iFormat(iFormat), m_pSeq(new qtractorMidiSequence()) {}
 
 		// Destructor.
 		~Data() { clear(); delete m_pSeq; }
