@@ -1,7 +1,7 @@
 // qtractorMidiEditEvent.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2021, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -467,6 +467,8 @@ void qtractorMidiEditEvent::updatePixmap ( int cx, int /*cy*/ )
 	painter.setPen(rgbLine);
 	painter.drawLine(0, y0, w, y0);
 
+	painter.setRenderHint(QPainter::Antialiasing, true);
+
 	// Draw ghost-track events in dimmed transparecncy (alpha=55)...
 	qtractorTrack *pTrack = m_pEditor->ghostTrack();
 	if (pTrack) {
@@ -491,7 +493,7 @@ void qtractorMidiEditEvent::updatePixmap ( int cx, int /*cy*/ )
 				const unsigned long t2 = pNode->tickFromFrame(iClipEnd);
 				drawEvents(painter, dx, y0, pMidiClip->sequence(),
 					t1, iTickStart, iTickEnd, t2, bDrumMode,
-					pTrack->foreground(), pTrack->background(), 55);
+					pTrack->foreground(), pTrack->background(), 60);
 			}
 			pClip = pClip->next();
 		}
@@ -504,6 +506,8 @@ void qtractorMidiEditEvent::updatePixmap ( int cx, int /*cy*/ )
 		t0, iTickStart, iTickEnd, iTickEnd2, m_pEditor->isDrumMode(),
 		m_pEditor->foreground(), m_pEditor->background());
 
+	painter.setRenderHint(QPainter::Antialiasing, false);
+
 	// Draw loop boundaries, if applicable...
 	if (pSession->isLooping()) {
 		const QBrush shade(QColor(0, 0, 0, 60));
@@ -583,6 +587,7 @@ void qtractorMidiEditEvent::drawEvents ( QPainter& painter,
 		|| eventType == qtractorMidiEvent::REGPARAM
 		|| eventType == qtractorMidiEvent::NONREGPARAM
 		|| eventType == qtractorMidiEvent::CONTROL14);
+	const int wm = m_pEditor->minEventWidth();
 
 	qtractorMidiEvent *pEvent
 		= m_pEditor->seekEvent(pSeq, iTickStart > t0 ? iTickStart - t0 : 0);
@@ -614,8 +619,8 @@ void qtractorMidiEditEvent::drawEvents ( QPainter& painter,
 			int w1 = (t1 >= t2 && m_pEditor->isClipRecord()
 				? m_pEditor->playHeadX()
 				: pNode->pixelFromTick(t2) - dx) - x;
-			if (w1 < 5 || !m_pEditor->isNoteDuration() || bDrumMode)
-				w1 = 5;
+			if (w1 < wm || !m_pEditor->isNoteDuration() || bDrumMode)
+				w1 = wm;
 			if (eventType == qtractorMidiEvent::NOTEON ||
 				eventType == qtractorMidiEvent::KEYPRESS) {
 				if (m_pEditor->isNoteColor()) {
@@ -628,6 +633,13 @@ void qtractorMidiEditEvent::drawEvents ( QPainter& painter,
 					rgbValue.setHsv(hue, sat, val, alpha);
 				}
 			}
+			// Lollipop candy shadow...
+			const QRect rect(x, y, wm, wm);
+			const int ym = (y > y0 - 5 ? -5 : 0); // negative pitch-bend adjust.
+			painter.setPen(rgbFore);
+			painter.setBrush(rgbFore);
+			painter.drawEllipse(rect.adjusted(-1, ym - 1, +1, ym + 1));
+			// Lollipop stick...
 			if (y < y0) {
 				painter.fillRect(x, y, w1, y0 - y, rgbFore);
 				painter.fillRect(x + 1, y + 1, w1 - 4, y0 - y - 2, rgbValue);
@@ -638,7 +650,13 @@ void qtractorMidiEditEvent::drawEvents ( QPainter& painter,
 				painter.fillRect(x, y0 - 2, w1, 4, rgbFore);
 				painter.fillRect(x + 1, y0 - 1, w1 - 4, 2, rgbValue);
 			}
-			if (m_pEditor->isNoteNames() && hs < y0 - y && (
+			// Lollipop candy hilite...
+			painter.setPen(rgbValue);
+			painter.setBrush(rgbValue);
+			painter.drawEllipse(rect.adjusted(0, ym, -2, ym - 2));
+			// Note name...
+			if (m_pEditor->isNoteNames() &&
+				m_pEditor->isNoteDuration() && hs < y0 - y && (
 				eventType == qtractorMidiEvent::NOTEON ||
 				eventType == qtractorMidiEvent::KEYPRESS)) {
 				const QString& sNoteName
