@@ -1,7 +1,7 @@
 // qtractorPluginForm.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2023, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -160,10 +160,13 @@ class qtractorPluginParamWidget : public QWidget
 
 public:
 
-	// Constructors.
+	// Constructor.
 	qtractorPluginParamWidget(qtractorPlugin::Param *pParam,
 		QWidget *pParent = nullptr);
 
+	// Destructor.
+	~qtractorPluginParamWidget();
+
 	// Refreshner-loader method.
 	void refresh();
 
