@@ -1,7 +1,7 @@
 // qtractorTimeScaleCommand.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -87,12 +87,19 @@ bool qtractorTimeScaleNodeCommand::addNode (void)
 	if (bPlaying)
 		pSession->seek(0, false);
 
+	qtractorTimeScale::Node *pNext = pNode->next();
+	const unsigned long iFrameStart = m_iFrame;
+	const unsigned long iFrameEnd
+		= (pNext ? pNext->frame : pSession->sessionEnd());
+
 	const float fOldTempo = pNode->tempo;
 	const float fNewTempo = m_fTempo;
 
 	const bool bRedoClipCommand = (m_pClipCommand == nullptr);
-	if (bRedoClipCommand)
-		m_pClipCommand = createClipCommand(pNode, fNewTempo, fOldTempo);
+	if (bRedoClipCommand) {
+		m_pClipCommand = createClipCommand(
+			iFrameStart, iFrameEnd, fNewTempo, fOldTempo);
+	}
 	else
 	if (m_pClipCommand) {
 		m_pClipCommand->undo();
@@ -103,9 +110,11 @@ bool qtractorTimeScaleNodeCommand::addNode (void)
 	pNode = m_pTimeScale->addNode(
 		m_iFrame, m_fTempo, m_iBeatType, m_iBeatsPerBar, m_iBeatDivisor);
 
+	m_iFrame = pNode->frame;
+
 	const bool bRedoCurveEditCommands = m_curveEditCommands.isEmpty();
 	if (bRedoCurveEditCommands) {
-		addCurveEditCommands(pNode, fNewTempo, fOldTempo);
+		addCurveEditCommands(iFrameStart, iFrameEnd, fNewTempo, fOldTempo);
 	} else {
 		QListIterator<qtractorCurveEditCommand *> undos(m_curveEditCommands);
 		while (undos.hasNext())
@@ -173,12 +182,19 @@ bool qtractorTimeScaleNodeCommand::updateNode (void)
 	const unsigned short iBeatsPerBar = pNode->beatsPerBar;
 	const unsigned short iBeatDivisor = pNode->beatDivisor;
 
+	qtractorTimeScale::Node *pNext = pNode->next();
+	const unsigned long iFrameStart = pNode->frame;
+	const unsigned long iFrameEnd
+		= (pNext ? pNext->frame : pSession->sessionEnd());
+
 	const float fOldTempo = pNode->tempo;
 	const float fNewTempo = m_fTempo;
 
 	const bool bRedoClipCommand = (m_pClipCommand == nullptr);
-	if (bRedoClipCommand)
-		m_pClipCommand = createClipCommand(pNode, fNewTempo, fOldTempo);
+	if (bRedoClipCommand) {
+		m_pClipCommand = createClipCommand(
+			iFrameStart, iFrameEnd, fNewTempo, fOldTempo);
+	}
 	else
 	if (m_pClipCommand) {
 		m_pClipCommand->undo();
@@ -188,7 +204,7 @@ bool qtractorTimeScaleNodeCommand::updateNode (void)
 
 	const bool bRedoCurveEditCommands = m_curveEditCommands.isEmpty();
 	if (bRedoCurveEditCommands) {
-		addCurveEditCommands(pNode, fNewTempo, fOldTempo);
+		addCurveEditCommands(iFrameStart, iFrameEnd, fNewTempo, fOldTempo);
 	} else {
 		QListIterator<qtractorCurveEditCommand *> undos(m_curveEditCommands);
 		while (undos.hasNext())
@@ -263,13 +279,20 @@ bool qtractorTimeScaleNodeCommand::removeNode (void)
 	if (bPlaying)
 		pSession->seek(0, false);
 
+	qtractorTimeScale::Node *pNext = pNode->next();
+	const unsigned long iFrameStart = pNode->frame;
+	const unsigned long iFrameEnd
+		= (pNext ? pNext->frame : pSession->sessionEnd());
+
 	qtractorTimeScale::Node *pPrev = pNode->prev();
 	const float fOldTempo = pNode->tempo;
 	const float fNewTempo = (pPrev ? pPrev->tempo : m_pTimeScale->tempo());
 
 	const bool bRedoClipCommand = (m_pClipCommand == nullptr);
-	if (bRedoClipCommand)
-		m_pClipCommand = createClipCommand(pNode, fNewTempo, fOldTempo);
+	if (bRedoClipCommand) {
+		m_pClipCommand = createClipCommand(
+			iFrameStart, iFrameEnd, fNewTempo, fOldTempo);
+	}
 	else
 	if (m_pClipCommand) {
 		m_pClipCommand->undo();
@@ -279,7 +302,7 @@ bool qtractorTimeScaleNodeCommand::removeNode (void)
 
 	const bool bRedoCurveEditCommands = m_curveEditCommands.isEmpty();
 	if (bRedoCurveEditCommands) {
-		addCurveEditCommands(pNode, fNewTempo, fOldTempo);
+		addCurveEditCommands(iFrameStart, iFrameEnd, fNewTempo, fOldTempo);
 	} else {
 		QListIterator<qtractorCurveEditCommand *> undos(m_curveEditCommands);
 		while (undos.hasNext())
@@ -328,21 +351,18 @@ bool qtractorTimeScaleNodeCommand::removeNode (void)
 
 // Make it automatic clip time-stretching command (static).
 qtractorClipCommand *qtractorTimeScaleNodeCommand::createClipCommand (
-	qtractorTimeScale::Node *pNode, float fNewTempo, float fOldTempo )
+	unsigned long iFrameStart, unsigned long iFrameEnd,
+	float fNewTempo, float fOldTempo )
 {
-	if (pNode == nullptr)
+	if (iFrameStart >= iFrameEnd)
 		return nullptr;
-	if (fNewTempo == fOldTempo)
+	if (qAbs(fNewTempo - fOldTempo) < 0.1f)
 		return nullptr;
 
 	qtractorSession *pSession = qtractorSession::getInstance();
 	if (pSession == nullptr)
 		return nullptr;
 
-	qtractorTimeScale::Node *pNext = pNode->next();
-	const unsigned long iFrameStart = pNode->frame;
-	const unsigned long iFrameEnd = (pNext ? pNext->frame : pSession->sessionEnd());
-
 	qtractorClipCommand *pClipCommand = nullptr;
 
 	for (qtractorTrack *pTrack = pSession->tracks().first();
@@ -382,21 +402,25 @@ qtractorClipCommand *qtractorTimeScaleNodeCommand::createClipCommand (
 
 // Automation curve time-stretching command (static).
 void qtractorTimeScaleNodeCommand::addCurveEditCommands (
-	qtractorTimeScale::Node *pNode, float fNewTempo, float fOldTempo )
+	unsigned long iFrameStart, unsigned long iFrameEnd,
+	float fNewTempo, float fOldTempo )
 {
-	if (pNode == nullptr)
+	if (iFrameStart >= iFrameEnd)
 		return;
-	if (fNewTempo == fOldTempo)
+	if (qAbs(fNewTempo - fOldTempo) < 0.1f)
 		return;
 
 	qtractorSession *pSession = qtractorSession::getInstance();
 	if (pSession == nullptr)
 		return;
 
-	const unsigned long iFrameStart = pNode->frame;
 	const float fFactor = (fOldTempo / fNewTempo);
 	const bool bReverse = (fOldTempo > fNewTempo);
 
+	const long iFrameDelta
+		= long(iFrameStart) - long(iFrameEnd)
+		+ long(float(iFrameEnd - iFrameStart) * fFactor);
+
 	for (qtractorTrack *pTrack = pSession->tracks().first();
 			pTrack; pTrack = pTrack->next()) {
 		qtractorCurveList *pCurveList = pTrack->curveList();
@@ -410,13 +434,22 @@ void qtractorTimeScaleNodeCommand::addCurveEditCommands (
 			qtractorCurve::Node *pCurveNode = (bReverse
 				? pCurve->nodes().last() : pCurve->seek(iFrameStart));
 			while (pCurveNode) {
+				if (pCurveNode->frame >= iFrameEnd) {
+					const unsigned long iFrame = pCurveNode->frame + iFrameDelta;
+					const float fValue = pCurveNode->value;
+					pCurveEditCommand->moveNode(pCurveNode, iFrame, fValue);
+					++iCurveEditUpdate;
+				}
+				else
 				if (pCurveNode->frame >= iFrameStart) {
 					const unsigned long iFrame = iFrameStart + (unsigned long)
 						(float(pCurveNode->frame - iFrameStart) * fFactor);
 					const float fValue = pCurveNode->value;
 					pCurveEditCommand->moveNode(pCurveNode, iFrame, fValue);
 					++iCurveEditUpdate;
-				} else if (bReverse)
+				}
+				else
+				if (bReverse)
 					break;
 				if (bReverse)
 					pCurveNode = pCurveNode->prev();
