@@ -1,7 +1,7 @@
 // qtractorVst3Plugin.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2023, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -72,10 +72,11 @@
 #endif
 
 #if 0//QTRACTOR_VST3_EDITOR_TOOL
-#include "qtractorMainForm.h"
 #include "qtractorOptions.h"
 #endif
 
+#include "qtractorMainForm.h"
+
 
 using namespace Steinberg;
 using namespace Linux;
@@ -1190,18 +1191,21 @@ int qtractorVst3PluginType::Impl::numChannels (
 		return -1;
 
 	int nchannels = 0;
+	int nactive = 0;
 
 	const int32 nbuses = m_component->getBusCount(type, direction);
 	for (int32 i = 0; i < nbuses; ++i) {
 		Vst::BusInfo busInfo;
 		if (m_component->getBusInfo(type, direction, i, busInfo) == kResultOk) {
-			if ((busInfo.busType == Vst::kMain) ||
-				(busInfo.flags & Vst::BusInfo::kDefaultActive))
+			if (busInfo.busType == Vst::kMain) {
 				nchannels += busInfo.channelCount;
+				if (busInfo.flags & Vst::BusInfo::kDefaultActive)
+					nactive += busInfo.channelCount;
+			}
 		}
 	}
 
-	return nchannels;
+	return (nactive > 0 ? nactive : nchannels);
 }
 
 
@@ -1819,7 +1823,7 @@ public:
 
 	// Constructor.
 	Handler (qtractorVst3Plugin *pPlugin)
-		: m_pPlugin(pPlugin) { FUNKNOWN_CTOR }
+		: m_pPlugin(pPlugin), m_restarting(false) { FUNKNOWN_CTOR }
 
 	// Destructor.
 	virtual ~Handler () { FUNKNOWN_DTOR }
@@ -1831,7 +1835,7 @@ public:
 	tresult PLUGIN_API beginEdit (Vst::ParamID /*id*/) override
 	{
 	#ifdef CONFIG_DEBUG_0
-		qDebug("vst3_text_plugin::Handler[%p]::beginEdit(%d)", this, int(id));
+		qDebug("qtractorVst3Plugin::Handler[%p]::beginEdit(%d)", this, int(id));
 	#endif
 		return kResultOk;
 	}
@@ -1839,19 +1843,21 @@ public:
 	tresult PLUGIN_API performEdit (Vst::ParamID id, Vst::ParamValue value) override
 	{
 	#ifdef CONFIG_DEBUG
-		qDebug("vst3_text_plugin::Handler[%p]::performEdit(%d, %g)", this, int(id), float(value));
+		qDebug("qtractorVst3Plugin::Handler[%p]::performEdit(%d, %g)", this, int(id), float(value));
 	#endif
 		m_pPlugin->impl()->setParameter(id, value, 0);
 		qtractorPlugin::Param *pParam = m_pPlugin->findParamId(int(id));
-		if (pParam)
+		if (pParam) {
+			pParam->setValueEnabled(true);
 			pParam->updateValue(float(value), false);
+		}
 		return kResultOk;
 	}
 
 	tresult PLUGIN_API endEdit (Vst::ParamID /*id*/) override
 	{
 	#ifdef CONFIG_DEBUG_0
-		qDebug("vst3_text_plugin::Handler[%p]::endEdit(%d)", this, int(id));
+		qDebug("qtractorVst3Plugin::Handler[%p]::endEdit(%d)", this, int(id));
 	#endif
 		return kResultOk;
 	}
@@ -1859,14 +1865,21 @@ public:
 	tresult PLUGIN_API restartComponent (int32 flags) override
 	{
 	#ifdef CONFIG_DEBUG
-		qDebug("vst3_text_plugin::Handler[%p]::restartComponent(0x%08x)", this, flags);
+		qDebug("qtractorVst3Plugin::Handler[%p]::restartComponent(0x%08x)", this, flags);
 	#endif
-		if (flags & Vst::kParamValuesChanged)
-			m_pPlugin->updateParamValues(false);
-		else
-		if (flags & Vst::kReloadComponent) {
-			m_pPlugin->impl()->deactivate();
-			m_pPlugin->impl()->activate();
+		if (!m_restarting) {
+			m_restarting = true;
+			if (flags & Vst::kReloadComponent)
+				m_pPlugin->impl()->deactivate();
+			m_pPlugin->resetParamValues(true);
+			QByteArray data;
+			if (m_pPlugin->impl()->getState(data))
+				m_pPlugin->impl()->setState(data);
+			m_pPlugin->updateParamValues(true);
+			m_pPlugin->resetParamValues(false);
+			if (flags & Vst::kReloadComponent)
+				m_pPlugin->impl()->activate();
+			m_restarting = false;
 		}
 		return kResultOk;
 	}
@@ -1886,6 +1899,8 @@ private:
 
 	// Instance client.
 	qtractorVst3Plugin *m_pPlugin;
+
+	bool m_restarting;
 };
 
 
@@ -2727,6 +2742,9 @@ void qtractorVst3Plugin::Impl::selectProgram ( int iBank, int iProg )
 //		/ Vst::ParamValue(m_programParamInfo.stepCount);
 	setParameter(id, value, 0);
 	controller->setParamNormalized(id, value);
+
+ 	// HACK: Make sure all displayed parameter values are in sync.
+	m_pPlugin->resetParamValues(false);
 }
 
 
@@ -3029,6 +3047,8 @@ void qtractorVst3Plugin::initialize (void)
 		snd_midi_event_new(c_iMaxMidiData, &m_pMidiParser) == 0)
 		snd_midi_event_no_status(m_pMidiParser, 1);
 
+	freezeConfigs();
+
 	// Instantiate each instance properly...
 	setChannels(channels());
 }
@@ -3133,7 +3153,7 @@ void qtractorVst3Plugin::deactivate (void)
 
 // Parameter update method.
 void qtractorVst3Plugin::updateParam (
-	qtractorPlugin::Param *pParam, float fValue, bool /*bUpdate*/ )
+	qtractorPlugin::Param *pParam, float fValue, bool bUpdate )
 {
 	qtractorVst3PluginType *pType
 		= static_cast<qtractorVst3PluginType *> (type());
@@ -3159,12 +3179,18 @@ void qtractorVst3Plugin::updateParam (
 	const Vst::ParamValue value = Vst::ParamValue(fValue);
 	m_pImpl->setParameter(id, value, 0);
 	controller->setParamNormalized(id, value);
+
+	pVst3Param->setValueEnabled(true);
 }
 
 
 // All parameters update method.
 void qtractorVst3Plugin::updateParamValues ( bool bUpdate )
 {
+#ifdef CONFIG_DEBUG_0
+	qDebug("qtractorVst3Plugin[%p]::updateParamValues(%d)", this, int(bUpdate));
+#endif
+
 	int nupdate = 0;
 
 	// Make sure all cached parameter values are in sync
@@ -3174,8 +3200,8 @@ void qtractorVst3Plugin::updateParamValues ( bool bUpdate )
 	const qtractorPlugin::Params::ConstIterator param_end = params.constEnd();
 	for ( ; param != param_end; ++param) {
 		Param *pParam = static_cast<Param *> (param.value());
-		if (pParam && pParam->impl()) {
-			Vst::ParamID id = pParam->impl()->paramInfo().id;
+		if (pParam && pParam->impl() && pParam->isValueEnabled()) {
+			const Vst::ParamID id = pParam->impl()->paramInfo().id;
 			const float fValue = float(m_pImpl->getParameter(id));
 			if (pParam->value() != fValue) {
 				pParam->setValue(fValue, bUpdate);
@@ -3189,6 +3215,22 @@ void qtractorVst3Plugin::updateParamValues ( bool bUpdate )
 }
 
 
+// Parameters enablement method.
+void qtractorVst3Plugin::resetParamValues ( bool bEnabled )
+{
+	const qtractorPlugin::Params& params = qtractorPlugin::params();
+	qtractorPlugin::Params::ConstIterator param = params.constBegin();
+	const qtractorPlugin::Params::ConstIterator param_end = params.constEnd();
+	for ( ; param != param_end; ++param) {
+		Param *pParam = static_cast<Param *> (param.value());
+		if (pParam)
+			pParam->setValueEnabled(bEnabled);
+	}
+
+	updateFormDirtyCount();
+}
+
+
 // Parameter finder (by id).
 qtractorPlugin::Param *qtractorVst3Plugin::findParamId ( int id ) const
 {
@@ -3208,6 +3250,8 @@ void qtractorVst3Plugin::configure (
 		qDebug("qtractorVst3Plugin[%p]::configure() data.size=%d", this, int(data.size()));
 	#endif
 		m_pImpl->setState(data);
+		// HACK: Make sure all parameter values are in sync.
+		resetParamValues(false);
 	}
 }
 
@@ -3566,7 +3610,7 @@ void qtractorVst3Plugin::selectProgram ( int iBank, int iProg )
 	m_pImpl->selectProgram(iBank, iProg);
 
 	// HACK: Make sure all displayed parameter values are in sync.
-	updateParamValues(false);
+	updateParamValues(true);
 }
 
 
@@ -3597,8 +3641,10 @@ bool qtractorVst3Plugin::loadPresetFile ( const QString& sFilename )
 		= m_pImpl->setState(file.readAll());
 
 	file.close();
+
 	// HACK: Make sure all displayed parameter values are in sync.
-	updateParamValues(false);
+	resetParamValues(false);
+
 	return bResult;
 }
 
@@ -3636,6 +3682,17 @@ bool qtractorVst3Plugin::savePresetFile ( const QString& sFilename )
 }
 
 
+// Make up some others dirty...
+void qtractorVst3Plugin::updateDirtyCount (void)
+{
+	qtractorMainForm *pMainForm = qtractorMainForm::getInstance();
+	if (pMainForm)
+		pMainForm->dirtyNotifySlot();
+
+	updateFormDirtyCount();
+}
+
+
 // Common host-time keeper (static)
 void qtractorVst3Plugin::updateTime ( qtractorAudioEngine *pAudioEngine )
 {
@@ -3657,7 +3714,8 @@ void qtractorVst3Plugin::clearAll (void)
 // Constructor.
 qtractorVst3Plugin::Param::Param (
 	qtractorVst3Plugin *pPlugin, unsigned long iIndex )
-	: qtractorPlugin::Param(pPlugin, iIndex), m_pImpl(nullptr)
+	: qtractorPlugin::Param(pPlugin, iIndex), m_pImpl(nullptr),
+		m_bValueEnabled(false)
 {
 	qtractorVst3PluginType *pType
 		= static_cast<qtractorVst3PluginType *> (pPlugin->type());
@@ -3672,8 +3730,8 @@ qtractorVst3Plugin::Param::Param (
 					m_pImpl = new Impl(paramInfo);
 					setName(fromTChar(paramInfo.title));
 					setMinValue(0.0f);
-					setMaxValue(1.0f);
-					setDefaultValue(controller->getParamNormalized(paramInfo.id));
+					setMaxValue(paramInfo.stepCount > 1 ? float(paramInfo.stepCount) : 1.0f);
+					setDefaultValue(float(controller->getParamNormalized(paramInfo.id)));
 				}
 			}
 		}
