@@ -1,7 +1,7 @@
 // qtractorVst3Plugin.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2023, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -109,6 +109,9 @@ public:
 	// Parameters update method.
 	void updateParamValues(bool bUpdate);
 
+	// Parameters enablement method.
+	void resetParamValues(bool bEnabled);
+
 	// Parameter finder (by id).
 	qtractorPlugin::Param *findParamId(int id) const;
 
@@ -181,6 +184,9 @@ protected:
 	// Internal accessors.
 	EditorFrame *editorFrame() const;
 
+	// Make up some others dirty...
+	void updateDirtyCount();
+
 private:
 
 	// Instance variables.
@@ -218,7 +224,7 @@ public:
 	// Destructor.
 	~Param();
 
-	// Port range hints predicate methods.
+	// Parameter range hints predicate methods.
 	bool isBoundedBelow() const;
 	bool isBoundedAbove() const;
 	bool isDefaultValue() const;
@@ -236,10 +242,18 @@ public:
 
 	Impl *impl() const { return m_pImpl; }
 
+	// Parameter enablement methods.
+	void setValueEnabled(bool bEnabled)
+		{ m_bValueEnabled = bEnabled; }
+	bool isValueEnabled() const
+		{ return m_bValueEnabled; }
+
 private:
 
 	// Instance variables.
 	Impl *m_pImpl;
+
+	bool  m_bValueEnabled;
 };
 
 
